% --- Source file: treat.Rd ---
\name{treat}
\alias{treat}
\title{TREe-based Association Test}
\description{
  A fast and powerful tree-based association test for detecting complex joint effects in case-control studies
}
\usage{
treat(formula, data, snp.vars, op=NULL) 
}
\arguments{
  \item{formula}{A \code{\link[stats]{formula}} describing the response and covariates. 
     The response must be binary. If the response is not 0-1, then it will be recoded to 0-1 and
      a warning will be printed. 
     The covariates must be categorical variables. If no covariates, use a formula similar to
      "Y ~ 1".}
  \item{data}{A data frame containing the response, covariates and SNPs. }
  \item{snp.vars}{Vector of column names and/or numbers for the SNPs. These variables must be coded as 0-1-2.
      If NULL, then all 0-1-2 variables in \code{data} that are not in the \code{formula} will be used
      as the SNP variables.}
  \item{op}{A list of options (see details). The default value is NULL.}
}
\value{
  The returned value is a list with names:
  \itemize{
  \item{\code{adj.pval}}{ The p-value of the TREE test, multiple-comparison adjusted. }
  \item{\code{unadj.pval}}{ Vector of p-values at each cut-point, calculated from the tree. }
  \item{\code{comment}}{ Status of the TREE test. It equals "done" if the estimated p-value is sufficiently accurate.
      It equals "refine" if the estimated p-value needs to be refined by more permutations. }
  \item{\code{adj.pval.back}}{ The p-value of the TREE test with backward searching, multiple-comparison adjusted. }
  \item{\code{unadj.pval.back}}{ Vector of p-values at each cut-point, calculated from the backward searching tree. }
  \item{\code{comment.back}}{ Status of the TREE test with backward searching. }
  \item{\code{tree.model.forward}}{ Data frame containing details of the built tree, 
       including how the node is split and which indicator is used as the splitting rule.
       If the condition in the column "rule" holds, then the sample is assigned to "child1(TRUE)" otherwise
       the sample is assigned to "child2(FALSE)". }
  \item{\code{tree.model.backward}}{ Details of the built tree with backward searching, 
       including how the node is split and merged, and which indicator is used as the splitting rule. }
  \item{\code{snps}}{ Final set of SNPs that were included in the analysis }
  \item{\code{rm.snps.coding}}{ SNPs that were removed due to coding errors }
  \item{\code{rm.snps.missRate}}{ SNPs the exceeded the maximum missing rate }
 } % END: itemize
 }

\details{  
   \bold{Missing values:}
    Any row of \code{data} containing a missing value for the response, covariates or any SNP will be removed from the analysis. \cr

  \bold{Options list:} \cr
 Below are the names for the options list \code{op}. All names have default values
         if they are not specified.
\itemize{
  \item{\code{backward}}{ <TRUE or FALSE> If TRUE, then the p-value is computed with backward searching as well. 
        The default is TRUE. }
  \item{\code{cut.point}}{ <Integer Vector> NULL or a vector of cut points.
                     If NULL, then it is set to 2:\code{nleaf}. The default is NULL.}
  \item{\code{nleaf}}{ <Integer> The maximum number of leaves in a tree. 
                   The default is 5. }
  \item{\code{nperm}}{ <Integer> Number of permutation steps for computing the p-value.
                 The default is 10000. }
  \item{\code{seed}}{ <Integer> Seed for random number generation. 
    If negative, the program will use the system time as the seed.
   The default is 0. }
  %\item{\code{trace}}{ <TRUE or FALSE> If TRUE, some details are printed when the tree is growing.
  %      The default is FALSE. }
  \item{\code{thr.grp.sample}}{ <Integer> The lower limit of the sample size of each category defined
     by the covariates in a node to be split.
         The default is 2. }
  \item{\code{thr.leaf.size}}{ <Integer> The minimum sample size for a leaf node in the tree.
            The default is 20. }
  \item{\code{thr.sample}}{ <Integer> The minimum sample size for a node to be split. 
   If the sample size in a node is less than \code{thr.sample}, the node will not be split. 
       The default is 50. }
  \item{\code{max.missRate}}{ <Number between 0 and 1> The maximum missing rate for each SNP.
   Any SNP with missing rate > \code{max.missRate} will be removed from the analysis.
   The default is 0.2.}

} % END: itemize


} % END: details

%\references{ }
\author{Han Zhang and Kai Yu }
\seealso{ \code{\link{treat.plink}} }
\examples{

  set.seed(123)

  # Create data
  y     <- c(rep(0, 1000), rep(1, 1000))
  covar <- sample(0:2, 2000, replace=TRUE, prob=rep(1/3,3))
  SNPs  <- matrix(rbinom(2000*10, 2, c(.36, .48, .16)), nrow=2000)
  SNPs  <- as.data.frame(SNPs)
  colnames(SNPs) <- paste("rs", 1:10, sep="")
  data  <- data.frame(y, covar, SNPs)

  tr <- treat(y~factor(covar), data=data, snp.vars=colnames(SNPs))

  tr$adj.pval
  tr$tree.model.forward

}

\keyword{model} 

